@@ -31,7 +31,11 @@
 #define KDE_DEFAULT_CHANGECURSOR true
 #define KDE_DEFAULT_LARGE_CURSOR false
 #define KDE_DEFAULT_WHEEL_ZOOM false
+#ifdef Q_WS_MAEMO_5
+#define KDE_DEFAULT_ICON_ON_PUSHBUTTON false
+#else
 #define KDE_DEFAULT_ICON_ON_PUSHBUTTON true
+#endif
 #define KDE_DEFAULT_OPAQUE_RESIZE true
 #define KDE_DEFAULT_BUTTON_LAYOUT 0
 #define KDE_DEFAULT_SHADE_SORT_COLUMN true
@@ -155,7 +159,9 @@ public:
      * @return the key that pops up context menus.
      * @deprecated Simply reimplement QWidget::contextMenuEvent() instead.
      */
+#ifndef KDE_NO_DEPRECATED
     static KDE_DEPRECATED int contextMenuKey ();
+#endif
 
     /**
      * Returns the KDE setting for context menus.
@@ -438,7 +444,7 @@ public:
      * @return Returns true if user wants to show icons.
      */
     static bool showIconsOnPushButtons();
-    
+
     /**
      * Returns true, if user visible strings should be sorted in a natural way:
      * image 1.jpg
@@ -452,7 +458,7 @@ public:
      * image 2.jpg
      *
      * @since 4.4
-     */     
+     */
     static bool naturalSorting();
 
     enum GraphicEffect {
@@ -515,6 +521,21 @@ public:
      */
     static QPalette createApplicationPalette(const KSharedConfigPtr &config = KSharedConfigPtr());
 
+    /**
+     * Used to obtain the QPalette that will be used to set the application palette.
+     *
+     * This is only useful for configuration modules such as krdb and should not be
+     * used in normal circumstances.
+     * @param config KConfig from which to load the colors (passed as-is to
+     * ::KColorScheme).
+     *
+     * @note The difference between this and the previous is that this never caches.
+     * @since 4.6.3
+     *
+     * @return the QPalette
+     */
+    static QPalette createNewApplicationPalette(const KSharedConfigPtr &config = KSharedConfigPtr());
+
     /**
      * An identifier for change signals.
      * \see emitChange
@@ -538,6 +559,17 @@ public:
      */
     static KGlobalSettings* self();
 
+    /**
+     * Specifies options passed to activate().
+     *
+     * @since 4.6
+     */
+    enum ActivateOption {
+        ApplySettings = 0x1, ///< Make all globally applicable settings take effect.
+        ListenForChanges = 0x2 ///< Listen for changes to the settings.
+    };
+    Q_DECLARE_FLAGS(ActivateOptions, ActivateOption)
+
     /**
      * Makes all globally applicable settings take effect
      * and starts listening for changes to these settings.
@@ -546,13 +578,21 @@ public:
      *
      * @since 4.3.3
      */
-    void activate();
+    void activate(); //KDE5: Merge with the overloaded method below
+
+    /**
+     * @overload
+     *
+     * @since 4.6
+     */
+    void activate(ActivateOptions options);
 
     /**
      * Valid values for the settingsChanged signal
      */
     enum SettingsCategory { SETTINGS_MOUSE, SETTINGS_COMPLETION, SETTINGS_PATHS,
-                            SETTINGS_POPUPMENU, SETTINGS_QT, SETTINGS_SHORTCUTS };
+                            SETTINGS_POPUPMENU, SETTINGS_QT, SETTINGS_SHORTCUTS,
+                            SETTINGS_LOCALE, SETTINGS_STYLE };
 
 Q_SIGNALS:
     /**
@@ -629,7 +669,7 @@ Q_SIGNALS:
      * Emitted by BlockShortcuts
      */
     void blockShortcuts(int data);
-    
+
     /**
      * Emitted when the natural sorting has been changed.
      * @since 4.4
@@ -648,5 +688,6 @@ private:
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KGlobalSettings::GraphicEffects)
+Q_DECLARE_OPERATORS_FOR_FLAGS(KGlobalSettings::ActivateOptions)
 
 #endif
