@@ -223,6 +223,9 @@ void Nepomuk::ResourceManagerPrivate::_k_dbusServiceUnregistered( const QString&
     if( serviceName == QLatin1String("org.kde.NepomukStorage") ) {
         kDebug() << "Nepomuk Storage service went down.";
         cleanupCache(-1);
+        if( m_manager->d->mainModel && m_manager->d->mainModel->isValid() ){
+            m_manager->d->mainModel->disconnect();
+        }
         emit m_manager->nepomukSystemStopped();
     }
 }
