@@ -48,6 +48,7 @@
 #include "plasma/theme.h"
 #include "plasma/view.h"
 #include "plasma/private/tooltip_p.h"
+#include "plasma/private/dialogshadows_p.h"
 
 namespace Plasma
 {
@@ -57,6 +58,7 @@ class ToolTipManagerPrivate
 public :
     ToolTipManagerPrivate(ToolTipManager *manager)
         : q(manager),
+          shadow(new DialogShadows(q, "widgets/tooltip")),
           currentWidget(0),
           showTimer(new QTimer(manager)),
           hideTimer(new QTimer(manager)),
@@ -90,6 +92,7 @@ public :
     void hideTipWidget();
 
     ToolTipManager *q;
+    DialogShadows *shadow;
     QGraphicsWidget *currentWidget;
     QTimer *showTimer;
     QTimer *hideTimer;
@@ -140,16 +143,18 @@ void ToolTipManager::show(QGraphicsWidget *widget)
         return;
     }
 
-    KConfig config("plasmarc");
-    KConfigGroup cg(&config, "PlasmaToolTips");
-    qreal delay = cg.readEntry("Delay", qreal(0.7));
-    if (delay < 0) {
+    d->delayedHide = false;
+    d->hideTimer->stop();
+    d->showTimer->stop();
+    const int defaultDelay = Theme::defaultTheme()->toolTipDelay();
+
+    if (defaultDelay < 0) {
         return;
     }
 
-    d->hideTimer->stop();
-    d->delayedHide = false;
-    d->showTimer->stop();
+    ToolTipContent content = d->tooltips[widget];
+    qreal delay = content.isInstantPopup() ? 0.0 : defaultDelay;
+
     d->currentWidget = widget;
 
     if (d->isShown) {
@@ -157,7 +162,7 @@ void ToolTipManager::show(QGraphicsWidget *widget)
         // which can be too much for less powerful CPUs to keep up with
         d->showTimer->start(200);
     } else {
-        d->showTimer->start(delay * 1000);
+        d->showTimer->start(qMax(qreal(200), delay));
     }
 }
 
@@ -209,6 +214,13 @@ void ToolTipManager::unregisterWidget(QGraphicsWidget *widget)
         return;
     }
 
+    if (widget == d->currentWidget) {
+        d->currentWidget = 0;
+        d->showTimer->stop();  // stop the timer to show the tooltip
+        d->delayedHide = false;
+        d->hideTipWidget();
+    }
+
     widget->removeEventFilter(this);
     d->removeWidget(widget);
 }
@@ -224,6 +236,7 @@ void ToolTipManager::setContent(QGraphicsWidget *widget, const ToolTipContent &d
 
     if (d->currentWidget == widget && d->tipWidget && d->tipWidget->isVisible()) {
         if (data.isEmpty()) {
+            // after this call, d->tipWidget will be null
             hide(widget);
         } else {
             d->delayedHide = data.autohide();
@@ -239,8 +252,17 @@ void ToolTipManager::setContent(QGraphicsWidget *widget, const ToolTipContent &d
         if (d->tipWidget) {
             d->tipWidget->setContent(widget, data);
             d->tipWidget->prepareShowing();
-            if (m_corona) {
-                d->tipWidget->moveTo(m_corona->popupPosition(widget, d->tipWidget->size(), Qt::AlignCenter));
+
+            //look if the data prefers aother graphicswidget, otherwise use the one used as event catcher
+            QGraphicsWidget *referenceWidget = data.graphicsWidget() ? data.graphicsWidget() : widget;
+            Corona *corona = qobject_cast<Corona *>(referenceWidget->scene());
+            if (!corona) {
+                // fallback to the corona we were given
+                corona = m_corona;
+            }
+
+            if (corona) {
+                d->tipWidget->moveTo(corona->popupPosition(referenceWidget, d->tipWidget->size(), Qt::AlignCenter));
             }
         }
     }
@@ -279,6 +301,8 @@ void ToolTipManagerPrivate::createTipWidget()
     }
 
     tipWidget = new ToolTip(0);
+    shadow->addWindow(tipWidget);
+
     QObject::connect(tipWidget, SIGNAL(activateWindowByWId(WId,Qt::MouseButtons,Qt::KeyboardModifiers,QPoint)),
                      q, SIGNAL(windowPreviewActivated(WId,Qt::MouseButtons,Qt::KeyboardModifiers,QPoint)));
     QObject::connect(tipWidget, SIGNAL(linkActivated(QString,Qt::MouseButtons,Qt::KeyboardModifiers,QPoint)),
@@ -335,14 +359,13 @@ void ToolTipManagerPrivate::clearTips()
 
 void ToolTipManagerPrivate::resetShownState()
 {
-    if (currentWidget) {
-        if (!tipWidget || !tipWidget->isVisible() || delayedHide) {
-            //One might have moused out and back in again
-            delayedHide = false;
-            isShown = false;
-            currentWidget = 0;
-            hideTipWidget();
-        }
+    if (!tipWidget || !tipWidget->isVisible() || delayedHide) {
+        //One might have moused out and back in again
+        showTimer->stop();
+        delayedHide = false;
+        isShown = false;
+        currentWidget = 0;
+        hideTipWidget();
     }
 }
 
@@ -360,13 +383,15 @@ void ToolTipManagerPrivate::showToolTip()
         return;
     }
 
-    // toolTipAboutToShow may call into methods such as setContent which play
-    // with the current widget; so let's just pretend for a moment that we don't have
-    // a current widget
-    QGraphicsWidget *temp = currentWidget;
-    currentWidget = 0;
-    QMetaObject::invokeMethod(temp, "toolTipAboutToShow");
-    currentWidget = temp;
+    if (currentWidget->metaObject()->indexOfMethod("toolTipAboutToShow()") != -1) {
+        // toolTipAboutToShow may call into methods such as setContent which play
+        // with the current widget; so let's just pretend for a moment that we don't have
+        // a current widget
+        QGraphicsWidget *temp = currentWidget;
+        currentWidget = 0;
+        QMetaObject::invokeMethod(temp, "toolTipAboutToShow");
+        currentWidget = temp;
+    }
 
     QHash<QGraphicsWidget *, ToolTipContent>::const_iterator tooltip = tooltips.constFind(currentWidget);
 
@@ -390,8 +415,15 @@ void ToolTipManagerPrivate::showToolTip()
     clickable = tooltip.value().isClickable();
     tipWidget->setContent(currentWidget, tooltip.value());
     tipWidget->prepareShowing();
-    if (q->m_corona) {
-        tipWidget->moveTo(q->m_corona->popupPosition(currentWidget, tipWidget->size(), Qt::AlignCenter));
+    QGraphicsWidget *referenceWidget = tooltip.value().graphicsWidget() ? tooltip.value().graphicsWidget() : currentWidget;
+    Corona *corona = qobject_cast<Corona *>(referenceWidget->scene());
+    if (!corona) {
+        // fallback to the corona we were given
+        corona = q->m_corona;
+    }
+
+    if (corona) {
+        tipWidget->moveTo(corona->popupPosition(referenceWidget, tipWidget->size(), Qt::AlignCenter));
     }
     tipWidget->show();
     isShown = true;  //ToolTip is visible
